# Python Easy Chromedriver Windows Install

This is a simple python package to install chromedriver on windows. Easy to use with selenium.

After configure use this pip command based on this example:

```pip install git+https://github.com/luan-grabher/easy-chromedriver-windows-install```

### Example

```python
from easy_chromedriver_windows_install import install_chromedriver

install_chromedriver() # install chromedriver
```
